
@import "@synerty/peek-plugin-base-js/src/styles/_variables";

:host {
    display: flex;
    flex-direction: column;
    width: 100%;
}

.action-buttons {
    display: flex;
    justify-content: flex-end;
    gap: $general_padding_1;
    margin-bottom: $general_margin_2;
}

.table-container {
    width: 100%;
    overflow: auto;
}

:host ::ng-deep {
    .ant-table-wrapper {
        width: 100%;
    }

    .ant-table-tbody > tr > td {
        padding: $general_padding_1;
    }

    .delete-button {
        color: $danger;
        &:hover {
            color: $danger_dark;
        }
    }
}